Repository: mesos
Updated Branches:
  refs/heads/master 52dfc2f00 -> 18f6642e2


Updated OCI protobuf messages with latest OCI image spec.

Review: https://reviews.apache.org/r/56851/


Project: http://git-wip-us.apache.org/repos/asf/mesos/repo
Commit: http://git-wip-us.apache.org/repos/asf/mesos/commit/87ca2fb0
Tree: http://git-wip-us.apache.org/repos/asf/mesos/tree/87ca2fb0
Diff: http://git-wip-us.apache.org/repos/asf/mesos/diff/87ca2fb0

Branch: refs/heads/master
Commit: 87ca2fb0c9d179616a6c1b70882edac783bca34b
Parents: 52dfc2f
Author: Qian Zhang <zhq527...@gmail.com>
Authored: Tue Mar 28 16:50:03 2017 +0800
Committer: Qian Zhang <zhq527...@gmail.com>
Committed: Tue Mar 28 16:50:03 2017 +0800

----------------------------------------------------------------------
 include/mesos/oci/spec.proto | 20 +++++++++++++++-----
 1 file changed, 15 insertions(+), 5 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/mesos/blob/87ca2fb0/include/mesos/oci/spec.proto
----------------------------------------------------------------------
diff --git a/include/mesos/oci/spec.proto b/include/mesos/oci/spec.proto
index 97f3cf3..f7f1979 100644
--- a/include/mesos/oci/spec.proto
+++ b/include/mesos/oci/spec.proto
@@ -29,6 +29,11 @@ message Descriptor {
   required string digest = 2;
   required int64 size = 3;
   repeated string urls = 4;
+
+  // NOTE: We cannot use 'annotations' here because otherwise,
+  // json->protobuf parsing will fail. 'Annotations' is manually
+  // set during parsing.
+  repeated Label Annotations = 5;
 }
 
 
@@ -50,8 +55,13 @@ message ManifestDescriptor {
   required string mediaType = 1;
   required string digest = 2;
   required int64 size = 3;
-  required Platform platform = 4;
+  optional Platform platform = 4;
   repeated string urls = 5;
+
+  // NOTE: We cannot use 'annotations' here because otherwise,
+  // json->protobuf parsing will fail. 'Annotations' is manually
+  // set during parsing.
+  repeated Label Annotations = 6;
 }
 
 
@@ -65,13 +75,13 @@ message Label {
 
 
 /**
  * Protobuf for the OCI image manifest list JSON schema:
  * https://github.com/opencontainers/image-spec/blob/master/manifest-list.md
  *
  * The OCI MIME type of this message is:
- *   application/vnd.oci.image.manifest.list.v1+json
+ *   application/vnd.oci.image.index.v1+json
  */
-message ManifestList {
+message Index {
   required int64 schemaVersion = 1;
   repeated ManifestDescriptor manifests = 2;
 
@@ -65,13 +75,13 @@ message Label {
 
 /**
- * Protobuf for the OCI image manifest list JSON schema:
- * https://github.com/opencontainers/image-spec/blob/master/manifest-list.md
+ * Protobuf for the OCI image index JSON schema:
+ * https://github.com/opencontainers/image-spec/blob/master/image-index.md
  *
  * The OCI MIME type of this message is:

Reply via email to